@@ -4,10 +4,6 @@
 #include <glib/gmacros.h>
 #include "procman.h"
 
-G_BEGIN_DECLS
-
 void procman_lsof(ProcData *data);
 
-G_END_DECLS
-
 #endif /* H_PROCMAN_LSOF_1161179202 */
