@@ -21,6 +21,7 @@
 
 #include <stdlib.h>
 
+#include <gtkmm.h>
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
@@ -42,6 +43,21 @@
 #include "util.h"
 #include "gconf-keys.h"
 
+
+
+ProcData::ProcData()
+  : tree(NULL),
+    cpu_graph(NULL),
+    mem_graph(NULL),
+    net_graph(NULL),
+    selected_process(NULL),
+    timeout(0),
+    disk_timeout(0),
+    cpu_total_time(1),
+    cpu_total_time_last(1)
+{ }
+
+
 ProcData* ProcData::get_instance()
 {
   static ProcData instance;
@@ -233,14 +249,6 @@ procman_data_new (GConfClient *client)
 	glibtop_cpu cpu;
 
 	pd = ProcData::get_instance();
-	
-	pd->tree = NULL;
-	pd->selected_process = NULL;
-	pd->timeout = 0;
-	pd->cpu_graph = NULL;
-	pd->mem_graph = NULL;
-	pd->net_graph = NULL;
-	pd->disk_timeout = 0;
 
 	/* username is usually 8 chars long
 	   for caching, we create chunks of 128 chars */
@@ -674,7 +682,7 @@ main (int argc, char *argv[])
 
 	startup_timestamp = get_startup_timestamp();
 
-	gtk_init(&argc, &argv);
+	Gtk::Main kit(&argc, &argv);
 	procman_debug("post gtk_init");
 
 	conn = bacon_message_connection_new ("gnome-system-monitor");
@@ -720,7 +728,7 @@ main (int argc, char *argv[])
 	create_main_window (procdata);
 	procman_debug("end create_main_window");
 	
-	proctable_update_all (procdata);
+	// proctable_update_all (procdata);
 
 	init_volume_monitor (procdata);
 
@@ -729,7 +737,7 @@ main (int argc, char *argv[])
  	gtk_widget_show(procdata->app);
        
 	procman_debug("begin gtk_main");
-	gtk_main ();
+	kit.run();
 	
 	procman_free_data (procdata);
 
