@@ -20,6 +20,7 @@
 #define _PROCMAN_PROCMAN_H_
 
 
+#include <gtkmm.h>
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <glib.h>
@@ -109,10 +110,10 @@ class ProcInfo
 	ProcInfo(pid_t pid);
 	~ProcInfo();
 	// adds one more ref to icon
-	void set_icon(GdkPixbuf *icon);
+	void set_icon(Glib::RefPtr<Gdk::Pixbuf> icon);
 
 	GtkTreeIter	node;
-	GdkPixbuf	*pixbuf;
+	Glib::RefPtr<Gdk::Pixbuf> pixbuf;
 	gchar		*tooltip;
 	gchar		*name;
 	gchar		*user; /* allocated with g_string_chunk, don't free it ! */
@@ -143,6 +144,14 @@ class ProcInfo
 
 	guint8		pcpu; /* 0% - 100% */
 	gint8		nice;
+
+// private:
+	// tracks cpu time per process keeps growing because if a
+	// ProcInfo is deleted this does not mean that the process is
+	// not going to be recreated on the next update.  For example,
+	// if dependencies + (My or Active), the proclist is cleared
+	// on each update.  This is a workaround
+	static std::map<pid_t, guint64> cpu_times;
 };
 
 struct ProcData
@@ -183,11 +192,19 @@ struct ProcData
 	unsigned	frequency;
 
 	SmoothRefresh  *smooth_refresh;
+
+	guint64 cpu_total_time;
+	guint64 cpu_total_time_last;
+
+private:
+	ProcData();
+	/* undefined */ ProcData(const ProcData &);
+	/* undefined */ ProcData& operator=(const ProcData &);
 };
 
-void		procman_save_config (ProcData *data) G_GNUC_INTERNAL;
-void		procman_save_tree_state (GConfClient *client, GtkWidget *tree, const gchar *prefix) G_GNUC_INTERNAL;
-gboolean	procman_get_tree_state (GConfClient *client, GtkWidget *tree, const gchar *prefix) G_GNUC_INTERNAL;
+void		procman_save_config (ProcData *data);
+void		procman_save_tree_state (GConfClient *client, GtkWidget *tree, const gchar *prefix);
+gboolean	procman_get_tree_state (GConfClient *client, GtkWidget *tree, const gchar *prefix);
 
 
 
